exceptiontools.MissingMeasureError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError

.. autoclass:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError.__unicode__
   :noindex:
